@@ -5,11 +5,14 @@
   vctrs::s3_register("ggplot2::autoplot", "tabnet_fit")
   vctrs::s3_register("ggplot2::autoplot", "tabnet_pretrain")
   vctrs::s3_register("ggplot2::autoplot", "tabnet_explain")
+  vctrs::s3_register("torch::nn_prune_head", "tabnet_fit")
+  vctrs::s3_register("torch::nn_prune_head", "tabnet_pretrain")
   vctrs::s3_register("tune::min_grid", "tabnet")
 }
 
 
 globalVariables(c("batch_size",
+                  "checkpoint",
                   "dataset",
                   "epoch",
                   "has_checkpoint",
